Core utillity functions
=======================


General helper functions in core
---------------------------------
    .. automodule:: aleksis.core.util.core_helpers
        :members:

Predicates for permission systemd
---------------------------------
.. automodule:: aleksis.core.util.predicates
        :members:

Messages
--------
.. automodule:: aleksis.core.util.messages
        :members:

General helper functions for models
-----------------------------------
.. automodule:: aleksis.core.util.model_helpers
        :members:

Helper functions for SASS
-------------------------
.. automodule:: aleksis.core.util.sass_helpers
        :members:

Utillity function for AlekSIS app container
-------------------------------------------
.. automodule:: aleksis.core.util.apps
        :members:

AlekSIS core middlewares
------------------------
.. automodule:: aleksis.core.util.middlewares
        :members:

Search utillity
------------------------
.. automodule:: aleksis.core.util.search
        :members:
